@@ -3,15 +3,12 @@
 #
 #  (C) Paul Evans, 2010-2017 -- leonerd@leonerd.org.uk
 
-package Protocol::IRC::Client;
+package Protocol::IRC::Client 0.13;
 
-use strict;
+use v5.14;
 use warnings;
-use 5.010; # //
 use base qw( Protocol::IRC );
 
-our $VERSION = '0.12';
-
 use Carp;
 
 =head1 NAME
@@ -647,7 +644,9 @@ sub prepare_hints_RPL_CHANNELMODEIS
 
 The following methods actually send IRC commands. Each is named after the
 underlying IRC command it sends, using capital letters for methods that simply
-send that command.
+send that command. They all take a kvlist of named parameters which is used to
+construct the message to send, by calling the
+L<Protocol::IRC::Message/new_from_named_args> constructor.
 
 =cut
 
@@ -655,6 +654,10 @@ send that command.
 
 =head2 do_NOTICE
 
+   $client->do_PRIVMSG( target => $user_or_channel, text => $message )
+
+   $client->do_NOTICE( target => $user_or_channel, text => $message )
+
 Sends a C<PRIVMSG> or C<NOTICE> command.
 
 For convenience, a single C<target> argument may be provided which will be
